summaryrefslogtreecommitdiffstats
path: root/appinfo/app.php
diff options
context:
space:
mode:
authorBernhard Posselt <nukeawhale@gmail.com>2013-04-15 21:23:37 +0200
committerBernhard Posselt <nukeawhale@gmail.com>2013-04-15 21:23:37 +0200
commitcbf9baf3c12ba38de86798bdf93aadc04c88d14b (patch)
treed2a5bed7b509cb1205fbaf7d0ba417c81aaa762a /appinfo/app.php
parent35ba857da23ccd7cd04d246d2a5f29269a5ccfdf (diff)
dont break if owncloud if appframework isnt enabled
Diffstat (limited to 'appinfo/app.php')
-rw-r--r--appinfo/app.php39
1 files changed, 20 insertions, 19 deletions
diff --git a/appinfo/app.php b/appinfo/app.php
index 584b47d62..98268df08 100644
--- a/appinfo/app.php
+++ b/appinfo/app.php
@@ -26,32 +26,33 @@ namespace OCA\News;
use \OCA\AppFramework\Core\API;
+// dont break owncloud when the appframework is not enabled
+if(\OCP\App::isEnabled('appframework')){
-$api = new API('news');
+ $api = new API('news');
-$api->addNavigationEntry(array(
+ $api->addNavigationEntry(array(
- // the string under which your app will be referenced in owncloud
- 'id' => $api->getAppName(),
+ // the string under which your app will be referenced in owncloud
+ 'id' => $api->getAppName(),
- // sorting weight for the navigation. The higher the number, the higher
- // will it be listed in the navigation
- 'order' => 10,
+ // sorting weight for the navigation. The higher the number, the higher
+ // will it be listed in the navigation
+ 'order' => 10,
- // the route that will be shown on startup
- 'href' => $api->linkToRoute('news_index'),
+ // the route that will be shown on startup
+ 'href' => $api->linkToRoute('news_index'),
- // the icon that will be shown in the navigation
- // this file needs to exist in img/example.png
- 'icon' => $api->imagePath('news.svg'),
+ // the icon that will be shown in the navigation
+ // this file needs to exist in img/example.png
+ 'icon' => $api->imagePath('news.svg'),
- // the title of your application. This will be used in the
- // navigation or on the settings page of your app
- 'name' => $api->getTrans()->t('News')
+ // the title of your application. This will be used in the
+ // navigation or on the settings page of your app
+ 'name' => $api->getTrans()->t('News')
-));
-
-
-$api->addRegularTask('OCA\News\Backgroundjob\Task', 'run');
+ ));
+ $api->addRegularTask('OCA\News\Backgroundjob\Task', 'run');
+} \ No newline at end of file